import {Content, ContentAccessor, ContentContent, QueryListOption} from "../../model/contents";
import {toQueryString} from './util';
const baseurl = "/content";

export * from "../../model/contents";
export class ClientContentAccessor implements ContentAccessor{
    async findList(option?: QueryListOption | undefined): Promise<Content[]>{
        let res = await fetch(`${baseurl}/search?${option !== undefined ? toQueryString(option) : ""}`);
        //if(res.status !== 200);
        let ret = await res.json();
        return ret;
    }
    async findById(id: number, tagload?: boolean | undefined): Promise<Content | undefined>{
        let res = await fetch(`${baseurl}/${id}`);
        if(res.status !== 200) return undefined;
        let ret = await res.json();
        return ret;
    }
    /**
     * not implement
     */
    async findListByBasePath(basepath: string): Promise<Content[]>{
        throw new Error("not implement");
        return [];
    }
    async update(c: Partial<Content> & { id: number; }): Promise<boolean>{
        const {id,...rest} = c;
        const res = await fetch(`${baseurl}/${id}`,{
            method: "POST",
            body: JSON.stringify(rest)
        });
        const ret = await res.json();
        return ret;
    }
    async add(c: ContentContent): Promise<number>{
        const res = await fetch(`${baseurl}`,{
            method: "POST",
            body: JSON.stringify(c)
        });
        const ret = await res.json();
        return ret;
    }
    async del(id: number): Promise<boolean>{
        const res = await fetch(`${baseurl}/${id}`,{
            method: "DELETE"
        });
        const ret = await res.json();
        return ret;
    }
    async addTag(c: Content, tag_name: string): Promise<boolean>{
        const {id,...rest} = c;
        const res = await fetch(`${baseurl}/${id}/tags/${tag_name}`,{
            method: "POST",
            body: JSON.stringify(rest)
        });
        const ret = await res.json();
        return ret;
    }
    async delTag(c: Content, tag_name: string): Promise<boolean>{
        const {id,...rest} = c;
        const res = await fetch(`${baseurl}/${id}/tags/${tag_name}`,{
            method: "DELETE",
            body: JSON.stringify(rest)
        });
        const ret = await res.json();
        return ret;
    }
}
export const CContentAccessor = new ClientContentAccessor;
export const makeThumbnailUrl = (x: Content)=>{
    return `/content/${x.id}/${x.content_type}/thumbnail`;
}

export default CContentAccessor;